import React, { Fragment } from 'react';
import { useFormik } from 'formik';
import { string, oneOfType, number, instanceOf, func, object, bool, arrayOf, shape } from 'prop-types';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var renderError = function renderError(showErrorWhenNotFocused, error, formik, name) {
  if (!showErrorWhenNotFocused) {
    return error && formik.touched[name] && /*#__PURE__*/React.createElement("div", {
      className: "form__error",
      "data-test": "error"
    }, error);
  }

  return error && /*#__PURE__*/React.createElement("div", {
    className: "form__error"
  }, error);
};

function Input(_ref) {
  var name = _ref.name,
      label = _ref.label,
      className = _ref.className,
      value = _ref.value,
      onChange = _ref.onChange,
      error = _ref.error,
      showErrorWhenNotFocused = _ref.showErrorWhenNotFocused,
      hideErrorMessage = _ref.hideErrorMessage,
      _ref$formik = _ref.formik,
      formik = _ref$formik === void 0 ? {} : _ref$formik,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      rest = _objectWithoutPropertiesLoose(_ref, ["name", "label", "className", "value", "onChange", "error", "showErrorWhenNotFocused", "hideErrorMessage", "formik", "type"]);

  return /*#__PURE__*/React.createElement("div", {
    className: "form__group " + className
  }, label && /*#__PURE__*/React.createElement("label", {
    htmlFor: name
  }, label), /*#__PURE__*/React.createElement("input", _extends({
    name: name,
    id: name,
    value: value,
    onChange: onChange,
    type: type,
    onBlur: !showErrorWhenNotFocused ? formik.handleBlur : function () {},
    className: "form__control form__input"
  }, rest)), !hideErrorMessage && renderError(showErrorWhenNotFocused, error, formik, name));
}

Input.propTypes = {
  name: string.isRequired,
  label: string,
  className: string,
  type: string,
  error: string,
  value: oneOfType([string, number, instanceOf(Date)]).isRequired,
  onChange: func.isRequired,
  formik: object,
  showErrorWhenNotFocused: bool,
  hideErrorMessage: bool
};

function Textarea(_ref) {
  var name = _ref.name,
      label = _ref.label,
      className = _ref.className,
      value = _ref.value,
      onChange = _ref.onChange,
      error = _ref.error,
      showErrorWhenNotFocused = _ref.showErrorWhenNotFocused,
      hideErrorMessage = _ref.hideErrorMessage,
      _ref$formik = _ref.formik,
      formik = _ref$formik === void 0 ? {} : _ref$formik,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      rest = _objectWithoutPropertiesLoose(_ref, ["name", "label", "className", "value", "onChange", "error", "showErrorWhenNotFocused", "hideErrorMessage", "formik", "type"]);

  return /*#__PURE__*/React.createElement("div", {
    className: "form__group " + className
  }, label && /*#__PURE__*/React.createElement("label", {
    htmlFor: name
  }, label), /*#__PURE__*/React.createElement("textarea", _extends({
    name: name,
    label: label,
    id: name,
    value: value,
    onChange: onChange,
    type: type,
    className: "form__control form__textarea",
    onBlur: !showErrorWhenNotFocused ? formik.handleBlur : function () {}
  }, rest)), !hideErrorMessage && renderError(showErrorWhenNotFocused, error, formik, name));
}

Textarea.propTypes = {
  name: string.isRequired,
  label: string,
  className: string,
  type: string,
  error: string,
  value: oneOfType([string, number, instanceOf(Date)]).isRequired,
  onChange: func.isRequired,
  formik: object,
  showErrorWhenNotFocused: bool,
  hideErrorMessage: bool
};

function Select(_ref) {
  var name = _ref.name,
      label = _ref.label,
      className = _ref.className,
      placeholder = _ref.placeholder,
      value = _ref.value,
      onChange = _ref.onChange,
      error = _ref.error,
      showErrorWhenNotFocused = _ref.showErrorWhenNotFocused,
      hideErrorMessage = _ref.hideErrorMessage,
      _ref$formik = _ref.formik,
      formik = _ref$formik === void 0 ? {} : _ref$formik,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      rest = _objectWithoutPropertiesLoose(_ref, ["name", "label", "className", "placeholder", "value", "onChange", "error", "showErrorWhenNotFocused", "hideErrorMessage", "formik", "options"]);

  return /*#__PURE__*/React.createElement("div", {
    className: "form__group " + className
  }, label && /*#__PURE__*/React.createElement("label", {
    htmlFor: name
  }, label), /*#__PURE__*/React.createElement("select", _extends({
    "data-test": "control",
    id: name,
    value: value,
    name: name,
    onChange: onChange,
    className: "form__control form__select"
  }, rest), /*#__PURE__*/React.createElement("option", {
    "data-test": "option",
    value: ""
  }, placeholder), options.map(function (_ref2, index) {
    var values = _ref2.values,
        placeholder = _ref2.placeholder;
    return /*#__PURE__*/React.createElement("option", {
      value: values,
      key: index
    }, placeholder);
  })), !hideErrorMessage && renderError(showErrorWhenNotFocused, error, formik, name));
}

Select.propTypes = {
  name: string.isRequired,
  label: string,
  className: string,
  placeholder: string,
  value: oneOfType([string, number]).isRequired,
  options: arrayOf(shape({
    id: oneOfType([string, number]).isRequired,
    label: oneOfType([string, number]).isRequired
  })).isRequired,
  onChange: func.isRequired,
  formik: object,
  showErrorWhenNotFocused: bool,
  hideErrorMessage: bool,
  error: string
};

function FormContainer(_ref) {
  var initialValues = _ref.initialValues,
      onSubmit = _ref.onSubmit,
      validationSchema = _ref.validationSchema,
      render = _ref.render;
  var formik = useFormik({
    initialValues: initialValues,
    onSubmit: onSubmit,
    validationSchema: validationSchema
  });

  var renderInput = function renderInput(props) {
    if (props === void 0) {
      props = {};
    }

    var _props = props,
        name = _props.name,
        label = _props.label,
        _onChange = _props.onChange,
        _props$showErrorWhenN = _props.showErrorWhenNotFocused,
        showErrorWhenNotFocused = _props$showErrorWhenN === void 0 ? false : _props$showErrorWhenN,
        rest = _objectWithoutPropertiesLoose(_props, ["name", "label", "onChange", "showErrorWhenNotFocused"]);

    var fieldProps = _extends({
      showErrorWhenNotFocused: showErrorWhenNotFocused,
      formik: formik,
      name: name,
      label: label,
      error: formik.errors[name],
      value: formik.values[name],
      onChange: function onChange(e) {
        formik.handleChange(e);
        if (_onChange) _onChange(e);
      }
    }, rest);

    return /*#__PURE__*/React.createElement(Input, fieldProps);
  };

  var renderTextarea = function renderTextarea(props) {
    if (props === void 0) {
      props = {};
    }

    var _props2 = props,
        name = _props2.name,
        label = _props2.label,
        _onChange2 = _props2.onChange,
        _props2$showErrorWhen = _props2.showErrorWhenNotFocused,
        showErrorWhenNotFocused = _props2$showErrorWhen === void 0 ? false : _props2$showErrorWhen,
        rest = _objectWithoutPropertiesLoose(_props2, ["name", "label", "onChange", "showErrorWhenNotFocused"]);

    var fieldProps = _extends({
      showErrorWhenNotFocused: showErrorWhenNotFocused,
      formik: formik,
      name: name,
      label: label,
      error: formik.errors[name],
      value: formik.values[name],
      onChange: function onChange(e) {
        formik.handleChange(e);
        if (_onChange2) _onChange2(e);
      }
    }, rest);

    return /*#__PURE__*/React.createElement(Textarea, fieldProps);
  };

  var renderSelect = function renderSelect(props) {
    if (props === void 0) {
      props = {};
    }

    var _props3 = props,
        name = _props3.name,
        label = _props3.label,
        options = _props3.options,
        _onChange3 = _props3.onChange,
        _props3$showErrorWhen = _props3.showErrorWhenNotFocused,
        showErrorWhenNotFocused = _props3$showErrorWhen === void 0 ? false : _props3$showErrorWhen,
        rest = _objectWithoutPropertiesLoose(_props3, ["name", "label", "options", "onChange", "showErrorWhenNotFocused"]);

    var fieldProps = _extends({
      showErrorWhenNotFocused: showErrorWhenNotFocused,
      formik: formik,
      options: options,
      label: label,
      name: name,
      value: formik.values[name],
      error: formik.errors[name],
      onChange: function onChange(e) {
        formik.handleChange(e);
        if (_onChange3) _onChange3(e);
      }
    }, rest);

    return /*#__PURE__*/React.createElement(Select, fieldProps);
  };

  var renderBtn = function renderBtn(props) {
    if (props === void 0) {
      props = {};
    }

    var _props4 = props,
        label = _props4.label,
        _props4$type = _props4.type,
        type = _props4$type === void 0 ? 'button' : _props4$type,
        rest = _objectWithoutPropertiesLoose(_props4, ["label", "type"]);

    return /*#__PURE__*/React.createElement("button", _extends({
      type: type
    }, rest), label);
  };

  var renderSubmitBtn = function renderSubmitBtn(props) {
    if (props === void 0) {
      props = {};
    }

    var _props5 = props,
        label = _props5.label,
        spinner = _props5.spinner,
        rest = _objectWithoutPropertiesLoose(_props5, ["label", "spinner"]);

    return /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement("button", _extends({
      disabled: !formik.isValid || formik.isSubmitting
    }, rest, {
      type: "submit"
    }), label), spinner && formik.isSubmitting && spinner);
  };

  var fieldProps = function fieldProps(name) {
    return {
      name: name,
      id: name,
      value: formik.values[name],
      onChange: formik.handleChange
    };
  };

  var data = {
    formik: formik,
    renderInput: renderInput,
    renderTextarea: renderTextarea,
    renderSelect: renderSelect,
    renderBtn: renderBtn,
    fieldProps: fieldProps,
    renderSubmitBtn: renderSubmitBtn
  };
  return render(data);
}

FormContainer.propTypes = {
  initialValues: object.isRequired,
  render: func.isRequired,
  onSubmit: func,
  validationSchema: object
};

export { FormContainer, Input, Select, Textarea };
//# sourceMappingURL=index.modern.js.map
